CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
90 lines
2.6 KiB
C++
90 lines
2.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip_test_checkers.hh>
|
|
|
|
/**
|
|
* @addtogroup hipMemcpyAtoHAsync hipMemcpyAtoHAsync
|
|
* @{
|
|
* @ingroup MemoryTest
|
|
* `hipError_t hipMemcpyAtoHAsync(void* dstHost, hipArray_t srcArray,
|
|
* size_t srcOffset, size_t ByteCount,
|
|
* hipStream_t stream)` -
|
|
* Copies from one 1D array to host memory.
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - This testcase initially copies data from host to 1D array and then performs
|
|
* hipMemcpyAtoHAsync api call and verifies with initial host values.
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/memory/hipMemcpyAtoHAsync.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipMemcpyAtoHAsync_Basic) {
|
|
#if HT_NVIDIA
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kApiUnsupportedOnNvidia);
|
|
#else
|
|
HIP_CHECK(hipSetDevice(0));
|
|
CHECK_IMAGE_SUPPORT
|
|
int row, col;
|
|
row = 1;
|
|
col = GENERATE(3, 4, 100);
|
|
int* A_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
|
|
int* B_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
|
|
for (int i = 0; i < (row * col); i++) {
|
|
A_h[i] = i;
|
|
}
|
|
hipArray_t A_a;
|
|
hipChannelFormatDesc desc = hipCreateChannelDesc<int>();
|
|
HIP_CHECK(hipMallocArray(&A_a, &desc, col, row, hipArrayDefault));
|
|
HIP_CHECK(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int), col * sizeof(int), row,
|
|
hipMemcpyHostToDevice));
|
|
HIP_CHECK(hipMemcpyAtoHAsync(B_h, A_a, 0, sizeof(int) * col * row, 0));
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
for (int i = 0; i < (row * col); i++) {
|
|
REQUIRE(A_h[i] == B_h[i]);
|
|
}
|
|
HIP_CHECK(hipFreeArray(A_a));
|
|
free(A_h);
|
|
free(B_h);
|
|
#endif
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipMemcpyAtoHAsync_Capture) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
constexpr int kRows = 1;
|
|
constexpr int kCols = 1;
|
|
auto host_data = std::make_unique<int[]>(kRows * kCols);
|
|
|
|
hipArray_t device_array = nullptr;
|
|
hipChannelFormatDesc channel_desc = hipCreateChannelDesc<int>();
|
|
HIP_CHECK(hipMallocArray(&device_array, &channel_desc, kCols, kRows, hipArrayDefault));
|
|
|
|
hipStream_t stream = nullptr;
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
|
|
GENERATE_CAPTURE();
|
|
BEGIN_CAPTURE(stream);
|
|
HIP_CHECK(
|
|
hipMemcpyAtoHAsync(host_data.get(), device_array, 0, sizeof(int) * kCols * kRows, stream));
|
|
END_CAPTURE(stream);
|
|
|
|
HIP_CHECK(hipFreeArray(device_array));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
|
|
/**
|
|
* End doxygen group MemoryTest.
|
|
* @}
|
|
*/
|